package com.ruoyi.caltools.model;

public class FlowProps {
    // 流量计算输入参数信息
    private int dFlowCalbz; // 流量计算标准


    private int dZcalbz; // 压缩因子计算标准
    private int dCbtj; // 计量参比条件压力
    private double dPb_M; // 计量参比条件压力
    private double dTb_M; // 计量参比条件温度
    private double dPb_E; // 燃烧参比条件压力
    private double dTb_E; // 燃烧参比条件温度
    private double dPatm; // 当地大气压
    private int dPatmUnit; // 当地大气压单位
    private String dngComponents; // 天然气组分

    private int dMeterType; // 流量计类别
    private int dCoreType; // 节流装置类型
    private int dPtmode; // 取压方式
    private int dPipeType; // 管道类型
    private double dPipeD; // 管道内径
    private int dLenUnit; // 长度单位
    private double dPipeDtemp; // 管道内径参考温度
    private int dPileDtempUint; // 温度单位
    private double dPipeMaterial; // 管道材料

    private double dOrificeD; // 孔板孔径
    private int dOrificeUnit; // 长度单位
    private double dOrificeDtemp; // 孔板内径参考温度
    private int dOrificeDtempUnit; // 温度单位
    private double dOrificeMaterial; // 孔板材料
    private int dOrificeSharpness; // 锐利度系数计算方法
    private double dOrificeRk; // 孔板入口圆弧半径
    private int dOrificeRkLenUint; // 长度单位
    private double dPf; // 输入压力
    private int dPfUnit; // 压力单位
    private int dPfType; // 压力类型
    private double dTf; // 输入温度
    private int dTfUnit; // 温度单位
    private double dDp; // 输入差压
    private int dDpUnit; // 压力单位
    private int dVFlowUnit; // 体积流量单位
    private int dMFlowUnit; // 质量流量单位
    private int dEFlowUnit; // 能量流量单位
    private double dCd; // 流出系数
    private double dMeterFactor; // 仪表系数
    private double dPulseNum; // 脉冲数
    private double dVFlowMax; // 最大体积流量
    private double dVFlowMin; // 最小体积流量
    private double dVFlowCon; // 常用流量
    private double dPfRange; // 压力量程
    private double dDpRange; // 差压量程
    private double dTfRange; // 温度计量程

    // 流量计算输出参数
    private double dE; // 求渐近速度系数 E
    private double dFG; // 求相对密度系数 FG
    private double dFT; // 求流动温度系数 FT



    private double dFpv; // 求超压缩因子 Fpv

    private double dDViscosity; // 求动力粘度 dlnd
    private double dDExpCoefficient; // 求可膨胀系数
    private double dRnPipe; // 管道雷诺数
    private double dBk; // 孔板锐利度系数Bk
    private double dRoughNessPipe; // 管道粗糙度系数 Gme
    private double dCdCorrect; // 修正后的流出系数
    private double dCdNozell; // 喷嘴的流出系数
    private double dVFlowb; // 标况体积流量 m³、s
    private double dVFlowf; // 工况体积流量
    private double dMFlowb; // 标况质量流量
    private double dEFlowb; // 标况能量流量
    private double dVelocityFlow; // 管道内天然气流速
    private double dPressLost; // 压力损失
    private double dBeta; // 直径比
    private double dKappa; // 等熵指数

    private int dNozzleType;  // 0圆环形喷嘴  2 圆柱形喉部文丘里喷嘴
    private  double dUpstreamRadius  ;//





    public double getdUpstreamRadius() {
        return dUpstreamRadius;
    }

    public void setdUpstreamRadius(double dUpstreamRadius) {
        this.dUpstreamRadius = dUpstreamRadius;
    }






    public int getdZcalbz() {
        return dZcalbz;
    }

    public void setdZcalbz(int dZcalbz) {
        this.dZcalbz = dZcalbz;
    }

    public int getdFlowCalbz() {
        return dFlowCalbz;
    }

    public void setdFlowCalbz(int dFlowCalbz) {
        this.dFlowCalbz = dFlowCalbz;
    }

    public int getdCbtj() {
        return dCbtj;
    }

    public void setdCbtj(int dCbtj) {
        this.dCbtj = dCbtj;
    }

    public double getdPb_M() {
        return dPb_M;
    }

    public void setdPb_M(double dPb_M) {
        this.dPb_M = dPb_M;
    }

    public double getdTb_M() {
        return dTb_M;
    }

    public void setdTb_M(double dTb_M) {
        this.dTb_M = dTb_M;
    }

    public double getdPb_E() {
        return dPb_E;
    }

    public void setdPb_E(double dPb_E) {
        this.dPb_E = dPb_E;
    }

    public double getdTb_E() {
        return dTb_E;
    }

    public void setdTb_E(double dTb_E) {
        this.dTb_E = dTb_E;
    }

    public double getdPatm() {
        return dPatm;
    }

    public void setdPatm(double dPatm) {
        this.dPatm = dPatm;
    }

    public int getdPatmUnit() {
        return dPatmUnit;
    }

    public void setdPatmUnit(int dPatmUnit) {
        this.dPatmUnit = dPatmUnit;
    }

    public String getdngComponents() {
        return dngComponents;
    }

    public void setdngComponents(String dngComponents) {
        this.dngComponents = dngComponents;
    }

    public int getdMeterType() {
        return dMeterType;
    }

    public void setdMeterType(int dMeterType) {
        this.dMeterType = dMeterType;
    }

    public int getdCoreType() {
        return dCoreType;
    }

    public void setdCoreType(int dCoreType) {
        this.dCoreType = dCoreType;
    }

    public int getdPtmode() {
        return dPtmode;
    }

    public void setdPtmode(int dPtmode) {
        this.dPtmode = dPtmode;
    }

    public int getdPipeType() {
        return dPipeType;
    }

    public void setdPipeType(int dPipeType) {
        this.dPipeType = dPipeType;
    }

    public double getdPipeD() {
        return dPipeD;
    }

    public void setdPipeD(double dPipeD) {
        this.dPipeD = dPipeD;
    }

    public int getdLenUnit() {
        return dLenUnit;
    }

    public void setdLenUnit(int dLenUnit) {
        this.dLenUnit = dLenUnit;
    }

    public double getdPipeDtemp() {
        return dPipeDtemp;
    }

    public void setdPipeDtemp(double dPipeDtemp) {
        this.dPipeDtemp = dPipeDtemp;
    }

    public int getdPileDtempUint() {
        return dPileDtempUint;
    }

    public void setdPileDtempUint(int dPileDtempUint) {
        this.dPileDtempUint = dPileDtempUint;
    }

    public double getdPipeMaterial() {
        return dPipeMaterial;
    }

    public void setdPipeMaterial(double dPipeMaterial) {
        this.dPipeMaterial = dPipeMaterial;
    }

    public double getdOrificeD() {
        return dOrificeD;
    }

    public void setdOrificeD(double dOrificeD) {
        this.dOrificeD = dOrificeD;
    }

    public int getdOrificeUnit() {
        return dOrificeUnit;
    }

    public void setdOrificeUnit(int dOrificeUnit) {
        this.dOrificeUnit = dOrificeUnit;
    }

    public double getdOrificeDtemp() {
        return dOrificeDtemp;
    }

    public void setdOrificeDtemp(double dOrificeDtemp) {
        this.dOrificeDtemp = dOrificeDtemp;
    }

    public int getdOrificeDtempUnit() {
        return dOrificeDtempUnit;
    }

    public void setdOrificeDtempUnit(int dOrificeDtempUnit) {
        this.dOrificeDtempUnit = dOrificeDtempUnit;
    }

    public double getdOrificeMaterial() {
        return dOrificeMaterial;
    }

    public void setdOrificeMaterial(double dOrificeMaterial) {
        this.dOrificeMaterial = dOrificeMaterial;
    }

    public int getdOrificeSharpness() {
        return dOrificeSharpness;
    }

    public void setdOrificeSharpness(int dOrificeSharpness) {
        this.dOrificeSharpness = dOrificeSharpness;
    }

    public double getdOrificeRk() {
        return dOrificeRk;
    }

    public void setdOrificeRk(double dOrificeRk) {
        this.dOrificeRk = dOrificeRk;
    }

    public int getdOrificeRkLenUint() {
        return dOrificeRkLenUint;
    }

    public void setdOrificeRkLenUint(int dOrificeRkLenUint) {
        this.dOrificeRkLenUint = dOrificeRkLenUint;
    }

    public double getdPf() {
        return dPf;
    }

    public void setdPf(double dPf) {
        this.dPf = dPf;
    }

    public int getdPfUnit() {
        return dPfUnit;
    }

    public void setdPfUnit(int dPfUnit) {
        this.dPfUnit = dPfUnit;
    }

    public int getdPfType() {
        return dPfType;
    }

    public void setdPfType(int dPfType) {
        this.dPfType = dPfType;
    }

    public double getdTf() {
        return dTf;
    }

    public void setdTf(double dTf) {
        this.dTf = dTf;
    }

    public int getdTfUnit() {
        return dTfUnit;
    }

    public void setdTfUnit(int dTfUnit) {
        this.dTfUnit = dTfUnit;
    }

    public double getdDp() {
        return dDp;
    }

    public void setdDp(double dDp) {
        this.dDp = dDp;
    }

    public int getdDpUnit() {
        return dDpUnit;
    }

    public void setdDpUnit(int dDpUnit) {
        this.dDpUnit = dDpUnit;
    }

    public int getdVFlowUnit() {
        return dVFlowUnit;
    }

    public void setdVFlowUnit(int dVFlowUnit) {
        this.dVFlowUnit = dVFlowUnit;
    }

    public int getdMFlowUnit() {
        return dMFlowUnit;
    }

    public void setdMFlowUnit(int dMFlowUnit) {
        this.dMFlowUnit = dMFlowUnit;
    }

    public int getdEFlowUnit() {
        return dEFlowUnit;
    }

    public void setdEFlowUnit(int dEFlowUnit) {
        this.dEFlowUnit = dEFlowUnit;
    }

    public double getdCd() {
        return dCd;
    }

    public void setdCd(double dCd) {
        this.dCd = dCd;
    }

    public double getdMeterFactor() {
        return dMeterFactor;
    }

    public void setdMeterFactor(double dMeterFactor) {
        this.dMeterFactor = dMeterFactor;
    }

    public double getdPulseNum() {
        return dPulseNum;
    }

    public void setdPulseNum(double dPulseNum) {
        this.dPulseNum = dPulseNum;
    }

    public double getdVFlowMax() {
        return dVFlowMax;
    }

    public void setdVFlowMax(double dVFlowMax) {
        this.dVFlowMax = dVFlowMax;
    }

    public double getdVFlowMin() {
        return dVFlowMin;
    }

    public void setdVFlowMin(double dVFlowMin) {
        this.dVFlowMin = dVFlowMin;
    }

    public double getdVFlowCon() {
        return dVFlowCon;
    }

    public void setdVFlowCon(double dVFlowCon) {
        this.dVFlowCon = dVFlowCon;
    }

    public double getdPfRange() {
        return dPfRange;
    }

    public void setdPfRange(double dPfRange) {
        this.dPfRange = dPfRange;
    }

    public double getdDpRange() {
        return dDpRange;
    }

    public void setdDpRange(double dDpRange) {
        this.dDpRange = dDpRange;
    }

    public double getdTfRange() {
        return dTfRange;
    }

    public void setdTfRange(double dTfRange) {
        this.dTfRange = dTfRange;
    }

    public double getdE() {
        return dE;
    }

    public void setdE(double dE) {
        this.dE = dE;
    }

    public double getdFG() {
        return dFG;
    }

    public void setdFG(double dFG) {
        this.dFG = dFG;
    }

    public double getdFT() {
        return dFT;
    }

    public void setdFT(double dFT) {
        this.dFT = dFT;
    }

    public double getdDViscosity() {
        return dDViscosity;
    }

    public void setdDViscosity(double dDViscosity) {
        this.dDViscosity = dDViscosity;
    }

    public double getdDExpCoefficient() {
        return dDExpCoefficient;
    }

    public void setdDExpCoefficient(double dDExpCoefficient) {
        this.dDExpCoefficient = dDExpCoefficient;
    }

    public double getdRnPipe() {
        return dRnPipe;
    }

    public void setdRnPipe(double dRnPipe) {
        this.dRnPipe = dRnPipe;
    }

    public double getdBk() {
        return dBk;
    }

    public void setdBk(double dBk) {
        this.dBk = dBk;
    }

    public double getdRoughNessPipe() {
        return dRoughNessPipe;
    }

    public void setdRoughNessPipe(double dRoughNessPipe) {
        this.dRoughNessPipe = dRoughNessPipe;
    }

    public double getdCdCorrect() {
        return dCdCorrect;
    }

    public void setdCdCorrect(double dCdCorrect) {
        this.dCdCorrect = dCdCorrect;
    }

    public double getdCdNozell() {
        return dCdNozell;
    }

    public void setdCdNozell(double dCdNozell) {
        this.dCdNozell = dCdNozell;
    }

    public double getdVFlowb() {
        return dVFlowb;
    }

    public void setdVFlowb(double dVFlowb) {
        this.dVFlowb = dVFlowb;
    }

    public double getdVFlowf() {
        return dVFlowf;
    }

    public void setdVFlowf(double dVFlowf) {
        this.dVFlowf = dVFlowf;
    }

    public double getdMFlowb() {
        return dMFlowb;
    }

    public void setdMFlowb(double dMFlowb) {
        this.dMFlowb = dMFlowb;
    }

    public double getdEFlowb() {
        return dEFlowb;
    }

    public void setdEFlowb(double dEFlowb) {
        this.dEFlowb = dEFlowb;
    }

    public double getdVelocityFlow() {
        return dVelocityFlow;
    }

    public void setdVelocityFlow(double dVelocityFlow) {
        this.dVelocityFlow = dVelocityFlow;
    }

    public double getdPressLost() {
        return dPressLost;
    }

    public void setdPressLost(double dPressLost) {
        this.dPressLost = dPressLost;
    }

    public double getdBeta() {
        return dBeta;
    }

    public void setdBeta(double dBeta) {
        this.dBeta = dBeta;
    }

    public double getdKappa() {
        return dKappa;
    }

    public void setdKappa(double dKappa) {
        this.dKappa = dKappa;
    }

    public double getdFpv() {
        return dFpv;
    }

    public void setdFpv(double dFpv) {
        this.dFpv = dFpv;
    }


    public int getdNozzleType() {
        return dNozzleType;
    }

    public void setdNozzleType(int dNozzleType) {
        this.dNozzleType = dNozzleType;
    }



}
